@@ -5,7 +5,7 @@ package PDL::Algorithm::Center::Failure;
 use strict;
 use warnings;
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 use custom::failures::x::alias -suffix => '_failure', qw[
   parameter
@@ -13,6 +13,16 @@ use custom::failures::x::alias -suffix => '_failure', qw[
   iteration::empty
 ];
 
+#
+# This file is part of PDL-Algorithm-Center
+#
+# This software is Copyright (c) 2017 by Smithsonian Astrophysical Observatory.
+#
+# This is free software, licensed under:
+#
+#   The GNU General Public License, Version 3, June 2007
+#
+
 1;
 
 __END__
@@ -27,7 +37,11 @@ PDL::Algorithm::Center::Failure - Exception classes for PDL::Algorithm::Center
 
 =head1 VERSION
 
-version 0.12
+version 0.13
+
+=for Pod::Coverage iteration_empty_failure
+iteration_limit_reached_failure
+parameter_failure
 
 =head1 SUPPORT
 
